@@ -10,7 +10,7 @@
 /* Define if your processor stores words with the most significant
    byte first (like Motorola and SPARC, unlike Intel and VAX).  */
 /* SID_WORDS_BIGENDIAN, SID_WORDS_LITTLEENDIAN  */
-#define SID_WORDS_BIGENDIAN
+#define SID_WORDS_LITTLEENDIAN
 
 /* Define if your C++ compiler implements exception-handling.  */
 #define SID_HAVE_EXCEPTIONS
